==> openrefine_3.5.2.orig.tar.xz: OpenRefine-3.5.2/docs/versioned_docs/version-3.4/manual/troubleshooting.md <==
---
id: troubleshooting
title: Troubleshooting
sidebar_label: Troubleshooting
---

## Frequently asked questions {#frequently-asked-questions}

We collect and share FAQs and responses on Github at [https://github.com/OpenRefine/OpenRefine/wiki/FAQ](https://github.com/OpenRefine/OpenRefine/wiki/FAQ).

If you don’t find your problem and solution there, continue on to the resources in the Community section below to see more conversations and look for solutions.  

## Community {#community}

### If you’re having a problem: {#if-youre-having-a-problem}
*   Search the [User forum](https://groups.google.com/g/openrefine) to see if the problem is already reported
*   Search [Github issues](https://github.com/OpenRefine/OpenRefine/issues) to see if the problem is already reported
*   Read [Stack Overflow](https://stackoverflow.com/questions/tagged/openrefine) to see if others had a similar problem
*   Check [Twitter](https://twitter.com/search?f=tweets&vertical=default&q=OpenRefine%20OR%20%22Open%20Refine%22%20OR%20%23OpenRefine&src=typd) to see if others are discussing the problem
*   Report an issue: 
    *   First as a new thread (conversation) in the [User forum](https://groups.google.com/g/openrefine).
    *   Then, if you wish, you can create a Github issue.

### If you want to contribute: {#if-you-want-to-contribute}
*   [Help us translate the tool into more languages](https://docs.openrefine.org/technical-reference/translating), using Weblate
*   [We have a guide to contributing](technical-reference/contributing) in the [Technical Reference](technical-reference/technical-reference-index) section
*   Contribute your feature requests in the [User forum](https://groups.google.com/g/openrefine) or as [Github issues](https://github.com/OpenRefine/OpenRefine/issues/new/choose)
*   Join the User Forum and/or the [Developer Forum](https://groups.google.com/g/openrefine-dev)
*   Share your successes and use cases with us, in the User forum
*   Add your [blog posts, guides, tips, tricks, tutorials to our list](https://github.com/OpenRefine/OpenRefine/wiki/External-Resources)
*   Keep an eye out for and respond to our biennial user survey.

==> openrefine_3.6.2.orig.tar.xz: OpenRefine-3.6.2/docs/versioned_docs/version-3.5/manual/troubleshooting.md <==
---
id: troubleshooting
title: Troubleshooting
sidebar_label: Troubleshooting
---

## Frequently asked questions {#frequently-asked-questions}

We collect and share FAQs and responses on Github at [https://github.com/OpenRefine/OpenRefine/wiki/FAQ](https://github.com/OpenRefine/OpenRefine/wiki/FAQ).

If you don’t find your problem and solution there, continue on to the resources in the Community section below to see more conversations and look for solutions.  

## Community {#community}

### If you’re having a problem: {#if-youre-having-a-problem}
*   Search the [User forum](https://groups.google.com/g/openrefine) to see if the problem is already reported
*   Search [Github issues](https://github.com/OpenRefine/OpenRefine/issues) to see if the problem is already reported
*   Read [Stack Overflow](https://stackoverflow.com/questions/tagged/openrefine) to see if others had a similar problem
*   Check [Twitter](https://twitter.com/search?f=tweets&vertical=default&q=OpenRefine%20OR%20%22Open%20Refine%22%20OR%20%23OpenRefine&src=typd) to see if others are discussing the problem
*   Report an issue: 
    *   First as a new thread (conversation) in the [User forum](https://groups.google.com/g/openrefine).
    *   Then, if you wish, you can create a Github issue.

### If you want to contribute: {#if-you-want-to-contribute}
*   [Help us translate the tool into more languages](../technical-reference/translating-ui), using Weblate
*   [We have a guide to contributing](../technical-reference/contributing) in the [Technical Reference](../technical-reference/technical-reference-index) section
*   Contribute your feature requests in the [User forum](https://groups.google.com/g/openrefine) or as [Github issues](https://github.com/OpenRefine/OpenRefine/issues/new/choose)
*   Join the User Forum and/or the [Developer Forum](https://groups.google.com/g/openrefine-dev)
*   Share your successes and use cases with us, in the User forum
*   Add your [blog posts, guides, tips, tricks, tutorials to our list](https://github.com/OpenRefine/OpenRefine/wiki/External-Resources)
*   Keep an eye out for and respond to our biennial user survey.
